%define anolis_release 6
%bcond_with liq
%bcond_with raqm
%bcond_with avif
%bcond_with heif

Summary:       A graphics library for quick creation of PNG or JPEG images
Name:          gd
Version:       2.3.3
Release:       %{anolis_release}%{?dist}
License:       MIT
URL:           http://libgd.github.io/
Source0:       https://github.com/libgd/libgd/releases/download/gd-%{version}/libgd-%{version}.tar.xz

# Missing header see https://github.com/libgd/libgd/pull/766
Patch0:        libgd-iostream.patch

BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(freetype2) >= 9.8.3
BuildRequires: pkgconfig(libjpeg)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(libtiff-4)
BuildRequires: pkgconfig(libwebp) >= 0.2.0
BuildRequires: pkgconfig(xpm)
BuildRequires: pkgconfig(zlib)
%if %{with liq}
BuildRequires: libimagequant-devel
%endif
%if %{with raqm}
BuildRequires: pkgconfig(raqm)
%endif
%if %{with avif}
BuildRequires: pkgconfig(libavif) >= 0.8.2
%endif
%if %{with heif}
BuildRequires: pkgconfig(libheif) >= 1.7.0
%endif
BuildRequires: perl-interpreter
BuildRequires: perl-generators
BuildRequires: perl(FindBin)
# for fontconfig/basic test
BuildRequires: cmake


%description
The gd graphics library allows your code to quickly draw images
complete with lines, arcs, text, multiple colors, cut and paste from
other images, and flood fills, and to write out the result as a PNG or
JPEG file. This is particularly useful in Web applications, where PNG
and JPEG are two of the formats accepted for inline images by most
browsers. Note that gd is not a paint program.


%package progs
Requires:       %{name} = %{version}-%{release}
Summary:        Utility programs that use libgd

%description progs
The gd-progs package includes utility programs supplied with gd, a
graphics library for creating PNG and JPEG images.


%package devel
Summary:  The development libraries and header files for gd
Requires: %{name} = %{version}-%{release}

%description devel
The gd-devel package contains the development libraries and header
files for gd, a graphics library for creating PNG and JPEG graphics.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%setup -q -n libgd-%{version}
%patch0 -p1

%build
# Provide a correct default font search path
CFLAGS="$RPM_OPT_FLAGS -DDEFAULT_FONTPATH='\"\
/usr/share/fonts/bitstream-vera:\
/usr/share/fonts/dejavu:\
/usr/share/fonts/default/Type1:\
/usr/share/X11/fonts/Type1:\
/usr/share/fonts/liberation\"'"

%ifarch aarch64
export CFLAGS="$CFLAGS -ffp-contract=off"
%endif

%cmake \
  -DENABLE_GD_FORMATS=1 \
  -DENABLE_PNG=1 \
  -DENABLE_JPEG=1 \
  -DENABLE_TIFF=1 \
  -DENABLE_ICONV=1 \
  -DENABLE_XPM=1 \
  -DENABLE_FREETYPE=1 \
  -DENABLE_FONTCONFIG=1 \
  -DENABLE_WEBP=1 \
%if %{with liq}
  -DENABLE_LIQ=1 \
%endif
%if %{with raqm}
  -DENABLE_RAQM=1 \
%endif
%if %{with avif}
  -DENABLE_AVIF=1 \
%endif
%if %{with heif}
  -DENABLE_HEIF=1 \
%endif
  -DENABLE_CPP=1
%cmake_build

%install
%cmake_install

rm -fr %{buildroot}%{_datadir}/doc/*

%generate_compatibility_deps

%files
%dir %{abidir}
%license COPYING
%{_libdir}/*.so.*
%{abidir}/libgd.dump
%{abidir}/webpng-option.list

%files progs
%{_bindir}/*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/gdlib.pc

%files doc
%doc CHANGELOG.md CONTRIBUTORS CONTRIBUTING.md README.md

%changelog
* Wed Apr 19 2023 Jing Zhang <renyu.zj@linux.alibaba.com> - 2.3.3-6
- Remove libgd-flip.patch

* Mon Mar 27 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 2.3.3-5
- Remove build require for liberation-sans-fonts
- Add abi file and doc pkg

* Thu Jan 19 2023 Funda Wang <fundawang@yeah.net> - 2.3.3-4
- Rebuild for new libtiff
- Use cmake to build

* Tue Apr 26 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.3.3-1
- init from upstream
